@@ -5,7 +5,6 @@ OC.L10N.register(
     "Provided email-address is not valid" : "Leveret e-mailadresse er ikke gyldig ",
     "%s has published the calendar »%s«" : "%s har oprettet en begivenhed i kalenderen »%s«",
     "Unexpected error sending email. Please contact your administrator." : "Uventet fejl ved afsendelse, venligst kontakt din administrator",
-    "Successfully sent email to " : "Email blev sendt til",
     "Hello," : "Hej,",
     "We wanted to inform you that %s has published the calendar »%s«." : "Vi ønkser at informerer dig om at %s har oprettet en begivenhed i kalenderen »%s«.",
     "Open »%s«" : "Åbn »%s«",
@@ -65,6 +64,7 @@ OC.L10N.register(
     "Creating calendar …" : "Opretter kalender…",
     "New calendar with task list" : "Ny kalender med opgaveliste",
     "Creating subscription …" : "Opretter abonnement…",
+    "Untitled event" : "Unavngiven begivenhed",
     "Import calendars" : "Importer kalendere",
     "Filename" : "Filnavn",
     "Cancel" : "Annullér",
@@ -88,7 +88,6 @@ OC.L10N.register(
     "Busy" : "Optaget",
     "Unknown" : "Ukendt",
     "Create Talk room for this event" : "Opret Snak rum for denne begivenhed",
-    "Send e-mail" : "Send e-mail",
     "Event title" : "Titel",
     "All day" : "Hele dagen",
     "from {startDate}" : "fra {startDate}",
@@ -122,9 +121,6 @@ OC.L10N.register(
     "Week {number} of {year}" : "Uge {number} i {year}",
     "Daily" : "Dagligt",
     "Weekly" : "Ugentligt",
-    "Untitled event" : "Unavngiven begivenhed",
-    "next year" : "næste år",
-    "today" : "i dag",
     "When shared show full event" : "Når delt, vis den fulde begivenhed",
     "When shared show only busy" : "Når delt, vis kun optaget",
     "When shared hide this event" : "Når delt, skjul denne begivenhed",
@@ -139,7 +135,6 @@ OC.L10N.register(
     "Review" : "Gennemse",
     "Office" : "Kontor",
     "Mail" : "Mail",
-    "Play" : "Afspil",
     "Global" : "Global"
 },
 "nplurals=2; plural=(n != 1);");
