@@ -34,7 +34,6 @@ OC.L10N.register(
     "Week {number} of {year}" : "สัปดาห์ที่ {number} ของปี {year}",
     "Daily" : "รุ่นรายวัน",
     "Weekly" : "รายสัปดาห์",
-    "today" : "วันนี้",
     "When shared show full event" : "เมื่อแชร์จะแสดงกิจกรรมทั้งหมด",
     "When shared show only busy" : "เมื่อแชร์จะแสดงเฉพาะไม่ว่าง",
     "When shared hide this event" : "เมื่อแชร์จะซ่อนกิจกรรมนี้",
@@ -45,7 +44,6 @@ OC.L10N.register(
     "Presentation" : "งานนำเสนอ",
     "Office" : "สำนักงาน",
     "Mail" : "จดหมาย",
-    "Play" : "เล่น",
     "Global" : "ทั่วไป"
 },
 "nplurals=1; plural=0;");
